@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2005-2017  Craig Barratt
+#   Copyright (C) 2005-2018  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #
 #========================================================================
 #
-# Version 4.1.3, released 3 Jun 2017.
+# Version 4.3.0, released 25 Nov 2018.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -69,6 +69,8 @@ our %ConfigMenu = (
             {text => "CfgEdit_Title_Pool_Filesystem_Limits"},
 	    {name => "DfCmd"},
 	    {name => "DfMaxUsagePct"},
+	    {name => "DfInodeUsageCmd"},
+	    {name => "DfMaxInodeUsagePct"},
 	    {name => "HardLinkMax"},
 
             {text => "CfgEdit_Title_Other_Parameters"},
@@ -125,6 +127,7 @@ our %ConfigMenu = (
             {name => "EMailNotifyMinDays"},
             {name => "EMailFromUserName"},
             {name => "EMailAdminUserName"},
+            {name => "EMailAdminSubject"},
             {name => "EMailUserDestDomain"},
 
             {text => "CfgEdit_Title_Email_User_Messages"},
@@ -168,6 +171,7 @@ our %ConfigMenu = (
 	    {name => "CgiUserUrlCreate"},
 
 	    {text => "CfgEdit_Title_User_Config_Editing"},
+	    {name => "CgiUserDeleteBackupEnable"},
 	    {name => "CgiUserConfigEditEnable"},
 	    {name => "CgiUserConfigEdit"},
         ],
@@ -347,6 +351,7 @@ our %ConfigMenu = (
 	    {name => "PingMaxMsec"},
 	    
 	    {text => "CfgEdit_Title_Other"},
+	    {name => "ClientComment"},
 	    {name => "ClientTimeout"},
 	    {name => "MaxOldPerPCLogFiles"},
 	    {name => "CompressLevel"},
@@ -465,8 +470,11 @@ sub action
             foreach my $paramInfo ( @{$ConfigMenu{$m}{param}} ) {
                 my $param = $paramInfo->{name};
                 if ( defined($paramInfo->{text}) ) {
-                    $text = $n;
-                    $mask[$text] = 1;
+                    $mask[$n] = 1;
+		    if ( ref($paramInfo->{visible}) ne "CODE"
+			    || &{$paramInfo->{visible}}($newConf, $bpc) ) {
+			$text = $n;
+		    }
                 } else {
                     if ( $bpc->{Conf}{CgiUserConfigEdit}{$param}
                           || (defined($bpc->{Conf}{CgiUserConfigEdit}{$param})
@@ -1190,7 +1198,7 @@ EOF
             if ( !$type->{noKeyEdit}
 		    && (keys(%$varValue) > 1 || $type->{emptyOk}) ) {
                 $content .= <<EOF;
-<input type="submit" name="del_${varName}_zZ_$fld" value="${EscHTML($Lang->{CfgEdit_Button_Delete})}"
+<input type="button" name="del_${varName}_zZ_$fld" value="${EscHTML($Lang->{CfgEdit_Button_Delete})}"
         onClick="deleteSubmit('${varName}_zZ_$fld')">
 EOF
             }
