@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2017  Craig Barratt
+#   Copyright (C) 2001-2018  Craig Barratt
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@
 #
 #========================================================================
 #
-# Version 4.1.3, released 3 Jun 2017.
+# Version 4.3.0, released 25 Nov 2018.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -57,7 +57,7 @@ sub action
     <td align="center" class="border"> $Jobs{$host}{type} </td>
     <td align="center" class="border"> ${UserLink(defined($Hosts->{$host})
 					? $Hosts->{$host}{user} : "")} </td>
-    <td class="border"> $startTime </td>
+    <td class="border" data-date_format="$Conf{CgiDateFormatMMDD}"> $startTime </td>
     <td class="border"> $cmd </td>
     <td align="center" class="border"> $Jobs{$host}{pid} </td>
     <td align="center" class="border"> $xferPid </td>
@@ -95,19 +95,20 @@ EOF
     <td align="center" class="border"> $Status{$host}{type} </td>
     <td align="center" class="border"> ${UserLink(defined($Hosts->{$host})
 					? $Hosts->{$host}{user} : "")} </td>
-    <td align="right" class="border"> $startTime </td>
+    <td align="right" class="border" data-date_format="$Conf{CgiDateFormatMMDD}"> $startTime </td>
     <td class="border"> $XferViewStr </td>
-    <td align="right" class="border"> $errorTime </td>
+    <td align="right" class="border" data-date_format="$Conf{CgiDateFormatMMDD}"> $errorTime </td>
     <td class="border"> ${EscHTML($shortErr)} </td></tr>
 EOF
     }
-    my $now          = timeStamp2(time);
-    my $nextWakeupTime = timeStamp2($Info{nextWakeup});
-    my $DUlastTime   = timeStamp2($Info{DUlastValueTime});
-    my $DUmaxTime    = timeStamp2($Info{DUDailyMaxTime});
-    my $numBgQueue   = $QueueLen{BgQueue};
-    my $numUserQueue = $QueueLen{UserQueue};
-    my $numCmdQueue  = $QueueLen{CmdQueue};
+    my $now             = timeStamp2(time);
+    my $nextWakeupTime  = timeStamp2($Info{nextWakeup});
+    my $DUlastTime      = timeStamp2($Info{DUlastValueTime});
+    my $DUmaxTime       = timeStamp2($Info{DUDailyMaxTime});
+    my $DUInodemaxTime  = timeStamp2($Info{DUInodeDailyMaxTime});
+    my $numBgQueue      = $QueueLen{BgQueue};
+    my $numUserQueue    = $QueueLen{UserQueue};
+    my $numCmdQueue     = $QueueLen{CmdQueue};
     my $serverStartTime = timeStamp2($Info{startTime});
     my $configLoadTime  = timeStamp2($Info{ConfigLTime});
 
@@ -127,8 +128,6 @@ EOF
     } elsif ( $Info{cpool4FileCnt} > 0 ) {
         $poolInfo = $cpoolInfo;
     }
-    my $generalInfo = eval("qq{$Lang->{BackupPC_Server_Status_General_Info}}")
-                                if ( $Privileged );
     my $generalInfo = "";
     if ( $Privileged ) {
         $generalInfo  = eval("qq{$Lang->{BackupPC_Server_Status_General_Info}}");
