@@ -90,9 +90,12 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
         <li>\$numUserQueue nevyzench dost o zlohu od uivatel,
         <li>\$numCmdQueue pending command requests,
         \$poolInfo
-        <li>Pool file system was recently at \$Info{DUlastValue}%
-            (\$DUlastTime), today\'s max is \$Info{DUDailyMax}% (\$DUmaxTime)
-            and yesterday\'s max was \$Info{DUDailyMaxPrev}%.
+        <li>Stav loit je \$Info{DUlastValue}%
+            (\$DUlastTime), dnen maximum je \$Info{DUDailyMax}% (\$DUmaxTime)
+                a verej maximum bylo \$Info{DUDailyMaxPrev}%.
+        <li>Inode stav loit je \$Info{DUInodelastValue}%
+            (\$DUlastTime), dnen maximum je \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+                a verej maximum bylo \$Info{DUInodeDailyMaxPrev}%.
     </ul>
 </ul>
 EOF
@@ -103,7 +106,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 <p>
 \${h2("Probhajc lohy")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td> Host </td>
     <td> Typ </td>
     <td> Uivatel </td>
@@ -122,7 +125,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 
 \${h2("Selhn, kter vyaduj pozornost")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Host </td>
     <td align="center"> Typ </td>
     <td align="center"> Uivatel </td>
@@ -145,7 +148,10 @@ $Lang{BackupPC_Summary} = <<EOF;
 <li>Tento stav byl vygenerovn v \$now.
 <li>Stav loit je \$Info{DUlastValue}%
     (\$DUlastTime), dnen maximum je \$Info{DUDailyMax}% (\$DUmaxTime)
-        a verej maximum bylo \$Info{DUDailyMaxPrev}%.
+    a verej maximum bylo \$Info{DUDailyMaxPrev}%.
+<li>Inode stav loit je \$Info{DUInodelastValue}%
+    (\$DUlastTime), dnen maximum je \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+    a verej maximum bylo \$Info{DUInodeDailyMaxPrev}%.
 </ul>
 </p>
 
@@ -162,6 +168,7 @@ $Lang{BackupPC_Summary} = <<EOF;
 <table class="sortable" id="host_summary_backups" border cellpadding="3" cellspacing="1">
 <tr class="tableheader"><td> Host </td>
     <td align="center"> Uivatel </td>
+    <td align="center"> Poznmka </td>
     <td align="center"> #Pln </td>
     <td align="center"> Pln as (dn) </td>
     <td align="center"> Pln Velikost (GiB) </td>
@@ -174,7 +181,6 @@ $Lang{BackupPC_Summary} = <<EOF;
     <td align="center"> Posledn pokus </td></tr>
 \$strGood
 </table>
-<br><br>
 \${h2("Host s dnmi provedenmi zlohami")}
 <p>
 \$hostCntNone host s dnmi zlohani.
@@ -309,6 +315,7 @@ EOF
 
 # --------------------------------
 $Lang{BackupPC__Backup_Requested_on__host} = "BackupPC:  Zloha vydna na \$host";
+$Lang{BackupPC__Delete_Requested_for_a_backup_of__host} = "BackupPC: Delete Requested for a backup of \$host";
 # --------------------------------
 $Lang{REPLY_FROM_SERVER} = <<EOF;
 \${h1(\$str)}
@@ -371,36 +378,36 @@ $Lang{BackupPC__Queue_Summary} = "BackupPC: Pehled front";
 # --------------------------------
 $Lang{Backup_Queue_Summary} = <<EOF;
 \${h1("Pehled fronty zlohovn")}
-<br><br>
 \${h2("Pehled fronty uivatel")}
 <p>
 Nsledujc uivatel jsou momentln ve front:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Host </td>
+    <td> Action </td>
     <td> as do </td>
     <td> Uivatel </td></tr>
 \$strUser
 </table>
-<br><br>
 
 \${h2("Souhrn fronty v pozad")}
 <p>
 Nsledujc dosti v pozad jsou momentln ve front:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Host </td>
+    <td> Action </td>
     <td> as do </td>
     <td> Uivatel </td></tr>
 \$strBg
 </table>
-<br><br>
 \${h2("Souhrn fronty pkaz")}
 <p>
 Nsledujc pkazy jsou momentln ve front:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Host </td>
+    <td> Action </td>
     <td> as do </td>
     <td> Uivatel </td>
     <td> Pkaz </td></tr>
@@ -429,7 +436,7 @@ $Lang{BackupPC__Log_File_History} = "BackupPC: Historie Log Souboru";
 $Lang{Log_File_History__hdr} = <<EOF;
 \${h1("Historie Log Souboru \$hdr")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Soubor </td>
     <td align="center"> Velikost </td>
     <td align="center"> as modifikace </td></tr>
@@ -441,7 +448,7 @@ EOF
 $Lang{Recent_Email_Summary} = <<EOF;
 \${h1("Pehled nedvnch email (azeno zptn)")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Pjemce </td>
     <td align="center"> Odeslatel </td>
     <td align="center"> as </td>
@@ -646,6 +653,34 @@ Odpov od serveru: \$reply
 EOF
 
 
+# --------------------------------
+$Lang{BackupPC__Delete_Backup_Confirm__num_of__host} = "BackupPC: Delete Backup Confirm #\$num of \$host";
+# --------------------------------
+$Lang{A_filled} = "a filled";
+$Lang{An_unfilled} = "an unfilled";
+$Lang{Are_you_sure_delete} = <<EOF;
+\${h1("Are you sure?")}
+<p>
+You are about to delete \$filled \$type backup #\$num of \$host.
+
+<form name="Confirm" action="\$MyURL" method="get">
+
+<input type="hidden" name="host" value="\${EscHTML(\$host)}">
+<input type="hidden" name="num" value="\$num">
+
+<input type="hidden" name="doit" value="1">
+<input type="hidden" name="action" value="">
+
+Do you really want to do this?
+
+<input type="button" value="\${EscHTML(\$Lang->{CfgEdit_Button_Delete})}"
+ onClick="document.Confirm.action.value='deleteBackup';
+          document.Confirm.submit();">
+
+<input type="submit" value="No" name="ignore">
+</form>
+EOF
+
 # -------------------------
 $Lang{Host__host_Backup_Summary} = "BackupPC: Pehled zloh hosta \$host";
 
@@ -675,7 +710,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <p>
 Kliknte na slo zlohy pro prohlen a obnoven zlohy.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Typ </td>
     <td align="center"> Vyplnno </td>
@@ -683,6 +718,7 @@ Kliknte na slo zlohy pro prohlen a obnoven zlohy.
     <td align="center"> Datum sputn </td>
     <td align="center"> Doba trvn/minuty </td>
     <td align="center"> Doba/dny </td>
+    \$deleteHdrStr
     <td align="center"> Cesta serveru zlohy </td>
 </tr>
 \$str
@@ -691,10 +727,8 @@ Kliknte na slo zlohy pro prohlen a obnoven zlohy.
 
 \$restoreStr
 </p>
-<br><br>
 \${h2("Pehled Xfer chyb")}
-<br><br>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Typ </td>
     <td align="center"> Pohled </td>
@@ -705,7 +739,6 @@ Kliknte na slo zlohy pro prohlen a obnoven zlohy.
 </tr>
 \$errStr
 </table>
-<br><br>
 
 \${h2("File Size/Count Reuse Summary")}
 <p>
@@ -713,13 +746,13 @@ Existujc soubory jsou ty, kter jsou ji v loiti; nov jsou pidan
 do loit.
 Przn soubory a SMB chyby nejsou potny.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="2" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Celkov </td>
     <td align="center" colspan="2"> Existujc soubory </td>
     <td align="center" colspan="2"> Nov soubory </td>
 </tr>
-<tr class="tableheader">
+<tr class="tableheader sortheader">
     <td align="center"> Zloha # </td>
     <td align="center"> Typ </td>
     <td align="center"> #Soubory </td>
@@ -732,19 +765,18 @@ Przn soubory a SMB chyby nejsou potny.
 </tr>
 \$sizeStr
 </table>
-<br><br>
 
 \${h2("Pehled kompres")}
 <p>
 Vkon komprese pro soubory, kter jsou ji v loiti a pro nov
 zkomprimovan soubory.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="3" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Existujc soubory </td>
     <td align="center" colspan="3"> Nov soubory </td>
 </tr>
-<tr class="tableheader"><td align="center"> Zloha # </td>
+<tr class="tableheader sortheader"><td align="center"> Zloha # </td>
     <td align="center"> Typ </td>
     <td align="center"> rove komprese </td>
     <td align="center"> Velikost/MB </td>
@@ -756,7 +788,6 @@ zkomprimovan soubory.
 </tr>
 \$compStr
 </table>
-<br><br>
 EOF
 
 $Lang{Host__host_Archive_Summary} = "BackupPC: Pehled archiv hosta \$host ";
@@ -896,7 +927,7 @@ ze vech zloh:
 <li> Klikni na odkaz verze souboru (\$Lang->{DirHistory_fileLink}0,
      \$Lang->{DirHistory_fileLink}1, ...) k jeho staen,
 <li> Soubory se stejnm obsahem v rznch zlohch maj stejn
-     slo verze,
+     slo verze (PleaseTranslateThis: except between v3 and v4 backups),
 <li> Soubory nebo adrese, kter nejsou ve vybran zloze 
      nejsou oznaeny.
 <li> Soubory zobrazen se stejnm slem verze mohou mt rozdln atributy.
@@ -1000,6 +1031,8 @@ $Lang{Only_privileged_users_can_view_log_files} = "Pouze oprvnn uivatel maj pstu
 $Lang{Only_privileged_users_can_view_email_summaries} = "Pouze oprvnn uivatel maj pstup k souhrnu email.";
 $Lang{Only_privileged_users_can_browse_backup_files} = "Pouze oprvnn uivatel mohou prohlet soubory zloh"
                 . " pro host \${EscHTML(\$In{host})}.";
+$Lang{Only_privileged_users_can_delete_backups} = "Only privileged users can delete backups"
+                . " of host \${EscHTML(\$host)}.";
 $Lang{Empty_host_name} = "Przdn jmno hosta.";
 $Lang{Directory___EscHTML} = "Adres \${EscHTML(\"\$TopDir/pc/\$host/\$num\")}"
 		    . " je przdn";
@@ -1050,6 +1083,8 @@ $Lang{Backup_requested_on__host_by__User} = "Zloha vydna z \$host uivatelem \$Us
 $Lang{Backup_stopped_dequeued_on__host_by__User} = "Zloha ukonena/vyazena z fronty z \$host uivatelem \$User";
 $Lang{Restore_requested_to_host__hostDest__backup___num} = "Obnova vydna na hosta \$hostDest, obnova #\$num,"
 	     . " uivatelem \$User z \$ENV{REMOTE_ADDR}";
+$Lang{Delete_requested_for_backup_of__host_by__User} = "Delete requested for backup #\$num of \$host"
+             . " by \$User from \$ENV{REMOTE_ADDR}";
 $Lang{Archive_requested} = "Archivace vydna uivatelem \$User z \$ENV{REMOTE_ADDR}";
 
 # -------------------------------------------------
@@ -1187,7 +1222,7 @@ $Lang{Restore_Summary} = <<EOF;
 \${h2("Obnovit souhrn")}
 <p>
 Klikni na obnoven pro vce detail.
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Obnoven # </td>
     <td align="center"> Vsledek </td>
     <td align="right"> Datum sputen</td>
@@ -1291,7 +1326,7 @@ Ujistte se, e je Vae PC pipojeno do st, a budete pt v kanceli.
 
 S pozdravem,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # No recent backup
@@ -1319,7 +1354,7 @@ nebudou moci bti obnoveny, pokud se disk ve Vaem potai pokod.
 
 S pozdravem,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # Old Outlook files
@@ -1349,7 +1384,7 @@ ke zjitn stavu zlohovn. Dokonen me trvat nkolik minut.
 
 S pozdravem,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 $Lang{howLong_not_been_backed_up} = "nebylo zlohovno spn";
@@ -1368,6 +1403,7 @@ Rychlost MB/sec: \$fullRate;
 Poet inkr: \$incrCnt;
 as inkr/Dn: \$incrAge;
 Stav: \$host_state;
+Zakzno: \$host_disabled;
 Posledn pokus: \$host_last_attempt;
 EOF
 
